@@ -8,7 +8,7 @@ from .scripts import sort_alpha
 from .scripts import sort_num
 
 class Collocates:
-    def __init__(self, filename, results_indices, before, after, word_count, group_by, mi_threshold=3, sample_size_threshold=2, search_string=''):
+    def __init__(self, filename, results_indices, before, after, word_count, group_by, mi_threshold=3, sample_size_threshold=2, search_string='', chunk_size=10000):
         self.filename = filename
         self.results_indices = results_indices
         self.results_count = len(results_indices)
@@ -19,6 +19,7 @@ class Collocates:
         self.mi_threshold = mi_threshold
         self.sample_size_threshold = sample_size_threshold
         self.search_string = search_string
+        self.chunk_size = chunk_size
 
         if self.results_count > 0:
             # Adds the self.collocates_before and self.collocates_after to Collocates class.
