@@ -9,8 +9,10 @@ class NGrams:
         self.group_by = kwargs['group_by']
         self.sep = kwargs['sep']
         self.text_filter = kwargs['text_filter']
+        self.cross_sentence_boundary = kwargs['cross_sentence_boundary']
         self.punct_pos = kwargs['punct_pos']
         self.chunk_num = kwargs['chunk_num']
+        self.chunk_size = kwargs['chunk_size']
         self.ngram_references = {}
         self.ngrams = self.calculate_ngrams()
         
@@ -20,7 +22,7 @@ class NGrams:
 
     def calculate_ngrams(self):
         ngram_dict = {}
-        self.elixir = pandas.read_csv(self.filename, sep='\t', escapechar='\\', index_col=None, header=0, chunksize=10000, keep_default_na=False)
+        self.elixir = pandas.read_csv(self.filename, sep='\t', escapechar='\\', index_col=None, header=0, chunksize=self.chunk_size, keep_default_na=False)
         # word_tracking will contain each words. Once it hits correct size or end of sentence, then reset the words.
         word_tracking = []
         current_citation = ''
@@ -37,11 +39,12 @@ class NGrams:
                 citation = self.get_citation(chunk, w)
                 # If the citation is not the same as the current_citation, then we've hit a new sentence.
                 # Words should not be in an ngram from different sentences.
-
-
-                # if citation != current_citation:
-                    # word_tracking = []
-                    # current_citation = citation
+                
+                if citation != current_citation:
+                    # Reset word_tracking if cross_sentence_boundary is set to False.
+                    if not self.cross_sentence_boundary:
+                        word_tracking = []
+                    current_citation = citation
 
                     
                 # Append the next word to word_tracking
@@ -89,3 +92,9 @@ class NGrams:
         elif isinstance(self.text_filter, list):
             pass
             # TODO: This is where a user could input ['Book of Mormon/1 Nephi/1/1'] to specify exact citation filtering.
+
+    def export_as_txt(self, filename):
+        with open(filename, 'w', encoding='utf-8') as file_out:
+            print(f'ngram\tfrequency', file=file_out)
+            for ngram in self.ngrams:
+                print(ngram[0], ngram[1], sep='\t', file=file_out)
\ No newline at end of file
