@@ -13,6 +13,7 @@ class SearchResults:
         self.punct_pos = kwargs['punct_pos']
         self.verbose = kwargs['verbose']
         self.text_filter = kwargs['text_filter']
+        self.chunk_size = kwargs['chunk_size']
         # Check for regex within text_filter
         if self.text_filter and 'is_regex' in self.text_filter:
             self.filter_regex = self.text_filter['is_regex']
@@ -69,7 +70,7 @@ class SearchResults:
                     # Set default distance to 1.
                     distance = 1
                 else:
-                    self.elixir = pandas.read_csv(self.filename, sep='\t', escapechar='\\', index_col=None, header=0, chunksize=10000)
+                    self.elixir = pandas.read_csv(self.filename, sep='\t', escapechar='\\', index_col=None, header=0, chunksize=self.chunk_size)
                     new_indices = []
                     for block_num, chunk in enumerate(self.elixir):
                         # Get the list of the current results indices based on the block number.
@@ -153,7 +154,7 @@ class SearchResults:
             results = []
         elif isinstance(search_word, list):
             results = {}
-        self.elixir = pandas.read_csv(self.filename, sep='\t', escapechar='\\', index_col=None, header=0, chunksize=10000)
+        self.elixir = pandas.read_csv(self.filename, sep='\t', escapechar='\\', index_col=None, header=0, chunksize=self.chunk_size)
         for block_num, chunk in enumerate(self.elixir):
             chunk = chunk.applymap(str)
             chunk = self.filter_chunk(chunk)
@@ -189,7 +190,7 @@ class SearchResults:
                             value = word_specs[wt_idx]
                             found_words = found_words[found_words[wt] == value]
                 for word in found_words.to_dict('index'):
-                    find_index = word-(block_num*10000)
+                    find_index = word-(block_num*self.chunk_size)
                     results.append((f'{block_num}:{find_index}',))
             # Collocates Handle
             elif isinstance(search_word, list):
@@ -226,7 +227,7 @@ class SearchResults:
         find_index = curr_index-1
         
         if find_index < 0:
-            find_index = 10000+curr_index-1
+            find_index = self.chunk_size+curr_index-1
             # If last_chunk is None, then we are at the beginning of block 0.
             if last_chunk is None:
                 return word_list
@@ -326,7 +327,7 @@ class SearchResults:
     ### VOCABULARY DISTRIBUTION HANDLER
     def vocab_distribution(self, **kwargs):
         group_by = kwargs['group_by'] if 'group_by' in kwargs else 0
-        return VocabDist(self.filename, group_by, self.results_indices, self.punct_pos, self.search_string)
+        return VocabDist(self.filename, group_by, self.results_indices, self.punct_pos, self.search_string, self.chunk_size)
 
     ### KWIC LINES HANDLER
     def kwic_lines(self, before=5, after=5, group_by='lower'):
@@ -342,7 +343,7 @@ class SearchResults:
         if group_by not in ['lemma', 'lower', 'pos', 'lower_pos', 'lemma_pos']:
             raise Exception(f"{{group_by}} value is invalid. It must be lemma, lower, pos, lower_pos, or lemma_pos.")
 
-        collocates = Collocates(self.filename, self.results_indices, before, after, self.word_count, group_by, mi_threshold=mi_threshold, sample_size_threshold=sample_size_threshold, search_string=self.search_string)
+        collocates = Collocates(self.filename, self.results_indices, before, after, self.word_count, group_by, mi_threshold=mi_threshold, sample_size_threshold=sample_size_threshold, search_string=self.search_string, chunk_size=self.chunk_size)
         # Set the totals for each word that was found as a collocate. This cannot be done in collocates.py because it depends on search_results.py, which also depends on collocates.py
         collocates.set_total(self.calculate_collocate_totals(collocates.sample))
         # Once totals are available, statistics can be calculated.
@@ -353,12 +354,12 @@ class SearchResults:
         print('Getting totals for each collocating word.')
         totals = {}
         words = [word for word, value in samples.items()]
-        totals = SearchResults(self.filename, words, self.word_count, punct_pos=self.punct_pos, verbose=False, text_filter=None, regex=False).results_totals
+        totals = SearchResults(self.filename, words, self.word_count, punct_pos=self.punct_pos, verbose=False, text_filter=None, regex=False, chunk_size=self.chunk_size).results_totals
         return totals
 
     ### SENTENCES HANDLER
     def sentences(self, group_by='text'):
-        return Sentences(self.filename, self.results_indices, group_by=group_by, search_string=self.search_string)
+        return Sentences(self.filename, self.results_indices, group_by=group_by, search_string=self.search_string, chunk_size=self.chunk_size)
 
     ### Frequency Distribution
     # 
\ No newline at end of file
