@@ -1,11 +1,12 @@
 import pandas
 
 class Sentences:
-    def __init__(self, filename, results_indices, group_by, search_string):
+    def __init__(self, filename, results_indices, group_by, search_string, chunk_size):
         self.filename = filename
         self.results_indices = results_indices
         self.group_by = group_by
         self.search_string = search_string
+        self.chunk_size = chunk_size
         if len(self.results_indices) > 0:
             self.sentence_index_ranges = self.calculate_sentence_indices()
             self.calculate_sentence_lines()
